@@ -15,6 +15,8 @@ needs serialization to the filesystem.
 
 =head1 ATTRIBUTES
 
+Inherits all attributes from superclass.
+
 =head2 dump_file
 
 This attribute is a string used to indicate in which file the data from L<Siebel::Srvmrgr::ListParser::Output::ListCompDef> should
@@ -64,7 +66,7 @@ sub BUILD {
 
     }
 
-    my $file = $params_ref->[0];
+    my $file = shift( @{$params_ref} );
 
     if ( ( defined($file) ) and ( $file ne '' ) ) {
 
@@ -85,29 +87,6 @@ sub BUILD {
 
 L<Siebel::Srvrmgr::Daemon::Action>
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
-
 =cut
 
 1;
