@@ -1,7 +1,7 @@
 package Siebel::Srvrmgr::ListParser::Output::ListParams;
 use Moose;
 use namespace::autoclean;
-use Carp;
+use feature qw(switch);
 
 =pod
 
@@ -74,6 +74,22 @@ Until now there is no method implementation that would return a parameter name a
 
 =head1 ATTRIBUTES
 
+=head2 params
+
+An array reference with the parameters attributes representing the output of the command C<list comp params>. If this description looks confusing, is the same
+columns shown in the command C<configure list params>.
+
+=cut
+
+has 'params' => (
+    is     => 'rw',
+    isa    => 'ArrayRef',
+    reader => 'get_params',
+    writer => 'set_params'
+);
+
+=pod
+
 =head2 server
 
 An string representing the server from where the parameter were got.
@@ -100,6 +116,16 @@ has comp_alias => (
 
 =pod
 
+=head1 METHODS
+
+=head2 get_params
+
+Returns the attribute params.
+
+=head2 set_params
+
+Set the attribute params. Expects an array reference as parameter.
+
 =head2 _set_details
 
 A "private" method used to get the servername and component alias from the command line given as parameter during object creation.
@@ -112,43 +138,32 @@ sub _set_details {
 
     if ( defined( $self->get_cmd_line() ) ) {
 
-      SWITCH: {
+        given ( $self->get_cmd_line() ) {
 
-            if ( $self->get_cmd_line() eq 'list params' ) {
+            when ('list params') {
                 $self->_set_server('connected server');
                 $self->_set_comp_alias('N/A');
-                last SWITCH;
             }
-            if (
-                $self->get_cmd_line() =~ /^list\sparams\sfor\scomponent\s\w+$/ )
-            {
+            when (/^list\sparams\sfor\scomponent\s\w+$/) {
                 $self->_set_server('connected server');
                 $self->_set_comp_alias(
                     ( split( /\s/, $self->get_cmd_line() ) )[-1] );
-                last SWITCH;
             }
-            if ( $self->get_cmd_line() =~ /^list\sparams\sfor\sserver\s\w+$/ ) {
+            when (/^list\sparams\sfor\sserver\s\w+$/) {
                 $self->_set_server(
                     ( split( /\s/, $self->get_cmd_line() ) )[-1] );
                 $self->_set_comp_alias('N/A');
-                last SWITCH;
             }
-            if ( $self->get_cmd_line() =~
-                /^list\sparams\sfor\sserver\s\w+\scomponent\s\w+$/ )
-            {
+            when (/^list\sparams\sfor\sserver\s\w+\scomponent\s\w+$/) {
 
                 my @values = split( /\s/, $self->get_cmd_line() );
 
                 $self->_set_server( $values[4] );
                 $self->_set_comp_alias( $values[6] );
-                last SWITCH;
 
             }
-            else {
-                confess 'got strange list params command: ('
-                  . $self->get_cmd_line()
-                  . ') do not know what do with it';
-            }
+
+            default { die "got strange list params command: cannot parse"; }
 
         }
 
@@ -168,48 +183,111 @@ sub BUILD {
 
     my $self = shift;
 
-    confess 'cmd_line attribute must have a string as a value, not ['
-      . $self->get_cmd_line() . ']'
-      unless ( $self->get_cmd_line() =~ /^\w+/ );
-
     $self->_set_details();
 
 }
 
-sub _set_header_regex {
+=pod
 
-    return qr/^PA_ALIAS\s.*\sPA_NAME/;
+=head2 parse
 
-}
+Parses the data in the C<raw_data> attribute setting the C<data_parsed> at the end of process.
 
-sub _parse_data {
+Beware that the C<raw_data> attribute will be set to an empty array reference at the end of the process.
 
-    my $self       = shift;
-    my $fields_ref = shift;
-    my $parsed_ref = shift;
+=cut
 
-    if ( @{$fields_ref} ) {
+sub parse {
 
-        my $pa_alias    = $fields_ref->[0];
-        my $list_len    = scalar( @{$fields_ref} );
-        my $columns_ref = $self->get_header_cols();
+    my $self = shift;
 
-        for ( my $i = 1 ; $i < $list_len ; $i++ )
-        {    # starting from 1 to skip the field PA_ALIAS
+    my $data_ref = $self->get_raw_data();
 
-            $parsed_ref->{$pa_alias}->{ $columns_ref->[$i] } =
-              $fields_ref->[$i];
+    my %parsed_lines;
+
+# removing the three last lines Siebel 7.5.3 (one blank line followed by a line amount of lines returned followed by a blank line)
+    for ( 1 .. 3 ) {
+
+        pop( @{$data_ref} );
+
+    }
+
+    foreach my $line ( @{$data_ref} ) {
+
+        chomp($line);
+
+      SWITCH: {
+
+            if ( $line =~ /^\-+\s/ ) {    # this is the header line
+
+                my @columns = split( /\s{2}/, $line );
+
+                my $pattern;
+
+                foreach my $column (@columns) {
+
+                    $pattern .= 'A'
+                      . ( length($column) + 2 )
+                      ; # + 2 because of the spaces after the "---" that will be trimmed
+
+                }
+
+                $self->_set_fields_pattern($pattern);
+
+                last SWITCH;
+
+            }
+
+            if ( $line eq '' ) {
+
+                last SWITCH;
+
+            }
+
+            #SV_NAME     CC_ALIAS
+            if ( $line =~ /^PA_ALIAS\s.*\sPA_NAME/ ) {    # this is the header
+
+                my @columns = split( /\s{2,}/, $line );
+
+                $self->set_params( \@columns );
+
+                last SWITCH;
+
+            }
+            else {
+
+                my @fields_values =
+                  unpack( $self->get_fields_pattern(), $line );
+
+                if (@fields_values) {
+
+                    my $pa_alias    = $fields_values[0];
+                    my $list_len    = scalar(@fields_values);
+                    my $columns_ref = $self->get_params();
+
+                    for ( my $i = 1 ; $i < $list_len ; $i++ )
+                    {    # starting from 1 to skip the field PA_ALIAS
+
+                        $parsed_lines{$pa_alias}->{ $columns_ref->[$i] } =
+                          $fields_values[$i];
+
+                    }
+
+                }
+                else {
+
+                    warn "got nothing\n";
+
+                }
+
+            }
 
         }
 
-        return 1;
-
     }
-    else {
 
-        return 0;
-
-    }
+    $self->set_data_parsed( \%parsed_lines );
+    $self->set_raw_data( [] );
 
 }
 
@@ -239,29 +317,6 @@ L<Storable>
 
 =back
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
-
 =cut
 
 no Moose;
