@@ -10,7 +10,6 @@ Siebel::Srvrmgr::ListParser::Output::LoadPreferences - subclass to parse load pr
 
 use Moose;
 use Siebel::Srvrmgr::Regexes;
-use feature 'switch';
 
 extends 'Siebel::Srvrmgr::ListParser::Output';
 
@@ -75,32 +74,29 @@ sub parse {
 
         chomp($line);
 
-        given ($line) {
+      SWITCH: {
 
-            when (/$response/) {
+            if ( $line =~ /$response/ ) {
 
                 my @data = split( /\:\s/, $line );
 
                 $self->set_location( $data[-1] );
                 $parsed_lines{answer} = $line;
 
+                last SWITCH;
+
             }
 
-            when ( $line =~ /$command/ ) {
+            if ( $line =~ /$command/ ) {
 
                 $parsed_lines{command} = $line;
+                last SWITCH;
 
             }
 
-            when ( $line eq '' ) {
+            if ( $line eq '' ) {
 
-                next;
-
-            }
-
-            default {
-
-                die 'Invalid data in line [' . $line . ']';
+                last SWITCH;
 
             }
 
@@ -132,29 +128,6 @@ L<Moose>
 
 =back
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
-
 =cut
 
 no Moose;
