@@ -1,9 +1,6 @@
 package Test::Daemon;
 
-use Cwd;
 use Test::Most;
-use File::Spec;
-use Test::Moose 'has_attribute_ok';
 use base 'Test::Class';
 
 sub class { 'Siebel::Srvrmgr::Daemon' }
@@ -14,7 +11,7 @@ sub startup : Tests(startup => 1) {
     use_ok $test->class;
 }
 
-sub constructor : Tests(43) {
+sub constructor : Tests(27) {
 
     my $test  = shift;
     my $class = $test->class;
@@ -47,16 +44,14 @@ sub constructor : Tests(43) {
 
     my $is_infinite = 0;
 
-    my $cmd = File::Spec->catfile( getcwd(), 't', 'srvrmgr-mock.pl' );
-
-# this data structure will make more sense when saw in use by the following foreach loop
+	# this data structure will make more sense when saw in use by the following foreach loop
     my @data = (
         [qw(get_server set_server foo)],
         [qw(get_gateway set_gateway bar)],
         [qw(get_enterprise set_enterprise foobar)],
         [qw(get_user set_user sadmin)],
         [qw(get_password set_password my_pass)],
-        [ 'get_bin', 'set_bin', $cmd ],
+        [qw(get_bin set_bin srvrmgr)],
         [ qw(get_wait_time set_wait_time 1)
         ] # :TRICKY:29/2/2012 17:50:36:: set_wait_time will return the value passed as parameter, so the ok function will complain if passed 0
     );
@@ -73,48 +68,31 @@ sub constructor : Tests(43) {
                 is_infinite => $is_infinite,
                 wait_time   => $data[6]->[2],
                 commands    => [
-                    Siebel::Srvrmgr::Daemon::Command->new(
+                    {
                         command => 'load preferences',
-                        action  => 'LoadPreferences'
-                    ),
-                    Siebel::Srvrmgr::Daemon::Command->new(
+                        action  => 'LoadPreferences',
+                    },
+                    {
                         command => 'list comp type',
                         action  => 'ListCompTypes',
                         params  => [$comp_types_file]
-                    ),
-                    Siebel::Srvrmgr::Daemon::Command->new(
+                    },
+                    {
                         command => 'list comp',
                         action  => 'ListComps',
                         params  => [$comps_file]
-                    ),
-                    Siebel::Srvrmgr::Daemon::Command->new(
+                    },
+                    {
                         command => 'list comp def',
                         action  => 'ListCompDef',
                         params  => [$comps_defs_file]
-                    )
+                    }
                 ]
             }
         ),
         '... and the constructor should succeed'
     );
 
-    has_attribute_ok( $daemon, 'server' );
-    has_attribute_ok( $daemon, 'gateway' );
-    has_attribute_ok( $daemon, 'enterprise' );
-    has_attribute_ok( $daemon, 'user' );
-    has_attribute_ok( $daemon, 'password' );
-    has_attribute_ok( $daemon, 'wait_time' );
-    has_attribute_ok( $daemon, 'commands' );
-    has_attribute_ok( $daemon, 'bin' );
-    has_attribute_ok( $daemon, 'write_fh' );
-    has_attribute_ok( $daemon, 'read_fh' );
-    has_attribute_ok( $daemon, 'pid' );
-    has_attribute_ok( $daemon, 'is_infinite' );
-    has_attribute_ok( $daemon, 'last_exec_cmd' );
-    has_attribute_ok( $daemon, 'cmd_stack' );
-    has_attribute_ok( $daemon, 'params_stack' );
-    has_attribute_ok( $daemon, 'action_stack' );
-
     foreach my $attrib (@data) {
 
         my $get = $attrib->[0];
@@ -131,24 +109,13 @@ sub constructor : Tests(43) {
 
     ok( $daemon->setup_commands(), 'setup_commands works' );
 
-    ok( $daemon->run(), 'run method executes successfuly' );
+	TODO: {
+	
+		local $TODO = 'must implement a srvrmgr mock to test run method';
 
-    # removes the dump files
-    my $dir = getcwd();
-
-    opendir( DIR, $dir ) or die "Cannot read $dir: $!\n";
-    my @files = readdir(DIR);
-    close(DIR);
-
-    foreach my $file (@files) {
-
-        if ( $file =~ /^dump\w/ ) {
-
-            unlink $file or die "Cannot remove $file: $!\n";
-
-        }
-
-    }
+		ok($daemon->run(), 'run method executes successfuly');
+	
+	}
 
 }
 
